@@ -767,7 +767,7 @@ class bfit(object):
             pass
         
         # get asymmetry: raw scans
-        if asym_type == 'r' and data.mode in ['1f', '1n', '1w']:
+        if asym_type == 'r' and data.mode in ['1f', '1n', '1w', '1c', '1d']:
             a = data.asym('raw', omit=option, hist_select=self.hist_select, 
                           nbm=self.use_nbm.get())
             x = np.arange(len(a.p[0]))
@@ -905,12 +905,15 @@ class bfit(object):
                           rebin=rebin, 
                           hist_select=self.hist_select, 
                           nbm=self.use_nbm.get())
-            try:
+            
+            # get x data
+            if 'custom' in a.keys():
+                x = a.custom
+                unit = data.ppg.scan_var_histo_factor.units
+                self.units[data.mode][1] = 'disable'
+            else:
                 x = a[self.x_tag[data.mode]]
-            except KeyError:
-                x = a['Custom EPICS scan']
-                
-            xlabel = self.xlabel_dict[data.mode]
+                xlabel = self.xlabel_dict[data.mode]
             
             # get bfit-defined units
             if data.mode in self.units.keys() and self.units[data.mode][1].lower() \
@@ -940,7 +943,7 @@ class bfit(object):
                 xlabel = xlabel % unit[1]
                         
             # unit conversions
-            if data.mode in ('1n', '1w'): 
+            if data.mode in ('1n', '1w', '1c', '1d'): 
                 x *= unit[0]
                 
             elif data.mode == '1f': 
