@@ -124,7 +124,7 @@ class fileviewer(object):
         
         ttk.Label(view_frame, text="Run Info").grid(column=0, row=0, sticky=N, pady=5)
         ttk.Label(view_frame, text="PPG Parameters").grid(column=1, row=0, sticky=N, pady=5)
-        ttk.Label(view_frame, text="Camp").grid(column=0, row=2, sticky=N, pady=5)
+        ttk.Label(view_frame, text="Camp and Stats").grid(column=0, row=2, sticky=N, pady=5)
         ttk.Label(view_frame, text="EPICS").grid(column=1, row=2, sticky=N, pady=5)
         
         self.text_nw.grid(column=0, row=1, sticky=(N, W, E, S), padx=5)
@@ -374,15 +374,30 @@ class fileviewer(object):
         except AttributeError:
             pass
     
+        # rf dac
+        if mode != 'SLR':
+            key_order_sw.append('')
+            try: 
+                data_sw['rf_dac'] = "%d" % int(data.camp.rf_dac.mean)
+                key_order_sw.append('rf_dac')
+            except AttributeError:
+                pass
+            
+            try: 
+                data_sw['RF Amplifier Gain'] = "%.2f" % data.camp.rfamp_rfgain.mean
+                key_order_sw.append('RF Amplifier Gain')
+            except AttributeError:
+                pass    
+        
         key_order_sw.append('')
         
         # rates and counts
         hist = ('F+', 'F-', 'B-', 'B+') if data.area == 'BNMR' \
                                      else ('L+', 'L-', 'R-', 'R+')
+
         try:     
             val = int(np.sum([data.hist[h].data for h in hist]))
             val, unit_val = num_prefix(val)
-            # ~ data_sw['Total Counts Sample'] = f'{val:,}'.replace(',', ' ')
             data_sw['Total Counts Sample'] = "%.3g%s" % (val, unit_val)
             key_order_sw.append('Total Counts Sample')
         except (AttributeError, KeyError):
@@ -406,8 +421,13 @@ class fileviewer(object):
             F, unit_F = num_prefix(F)
             B, unit_B = num_prefix(B)
             
+            try:
+                ratio = F/B
+            except ZeroDivisionError:
+                ratio = np.nan
+            
             data_sw['Rate %s/%s' % (tag_F, tag_B)] = \
-                    '%.3g%s / %.3g%s (cps) [ratio: %.2f]' % (F, unit_F, B, unit_B, F/B)
+                    '%.3g%s / %.3g%s (cps) [ratio: %.2f]' % (F, unit_F, B, unit_B, ratio)
             key_order_sw.append('Rate %s/%s' % (tag_F, tag_B))
         except (AttributeError, KeyError):
             pass
@@ -418,7 +438,6 @@ class fileviewer(object):
         try: 
             val = int(np.sum([data.hist['NBM'+h].data for h in hist]))
             val, unit_val = num_prefix(val)
-            # ~ data_sw['Total Counts NBM'] = f'{val:,}'.replace(',', ' ')
             data_sw['Total Counts NBM'] = "%.3g%s" % (val, unit_val)
             key_order_sw.append('Total Counts NBM')
         except (AttributeError, KeyError):
@@ -428,26 +447,10 @@ class fileviewer(object):
             val = int(np.sum([data.hist['NBM'+h].data for h in hist])/data.duration)
             val, unit_val = num_prefix(val)
             data_sw['Total Rate NBM'] = "%.3g%s (cps)" % (val, unit_val)
-            # ~ data_sw['Total Rate NBM'] = f'{val:,} (1/s)'.replace(',', ' ')
             key_order_sw.append('Total Rate NBM')
         except (AttributeError, KeyError):
             pass
             
-        # rf dac
-        if mode != 'SLR':
-            key_order_sw.append('')
-            try: 
-                data_sw['rf_dac'] = "%d" % int(data.camp.rf_dac.mean)
-                key_order_sw.append('rf_dac')
-            except AttributeError:
-                pass
-            
-            try: 
-                data_sw['RF Amplifier Gain'] = "%.2f" % data.camp.rfamp_rfgain.mean
-                key_order_sw.append('RF Amplifier Gain')
-            except AttributeError:
-                pass    
-        
         # SE -----------------------------------------------------------------
         data_se = {'':''}
         key_order_se = []
